@@ -258,9 +258,12 @@ static List			   *records_cache;	/* List of SennaRecordsCache */
 static int RELOPT_KIND_SENNA;
 #endif
 
+#define DEFAULT_INITIAL_N_SEGMENTS			512
+
 #define SennaInitialSegments(relation) \
 	((relation)->rd_options ? \
-	 ((SennaOptions *) (relation)->rd_options)->initial_n_segments : 8)
+	 ((SennaOptions *) (relation)->rd_options)->initial_n_segments : \
+	 DEFAULT_INITIAL_N_SEGMENTS)
 
 /* copied from adt/genfile.c */
 static char *
@@ -1001,7 +1004,6 @@ senna_options(PG_FUNCTION_ARGS)
 					validate, tab, lengthof(tab));
 
 	pfree(options);
-
 	PG_RETURN_BYTEA_P(rdopts);
 }
 
@@ -1670,6 +1672,11 @@ _PG_init(void)
 
 #if PG_VERSION_NUM >= 80400
 	RELOPT_KIND_SENNA = add_reloption_kind();
+	add_int_reloption(RELOPT_KIND_SENNA,
+		"initial_n_segments",
+		"initial size of .sen.i",
+		DEFAULT_INITIAL_N_SEGMENTS,
+		1, INT_MAX);
 #endif
 
 	sen_logger_info_set(&senna_logger);
